package dom;

import dom2app.PizzaTypeSummaryInterface;

public class PizzaTypeSummary implements PizzaTypeSummaryInterface{
	private String typeName;
	private int numberOfOrders;
	private int numberOfPizzas;
	private int totalRevenue;
	
	/**
	 * Creates a new reporting-purpose PizzaSummaryType
	 * 
	 *  Destined to contain the aggregate summaries of all the orders of the same type.
	 *  
	 * @param typeName a String with the type of pizza
	 * @param numberOfOrders an int with the number of distinct orders of this type
	 * @param numberOfPizzas an int with the number of total pizzas ordered for this type 
	 * @param summaryPrice an int with the total money collected
	 * @throws IllegalArgumentException with empty type names, and, negative numerical quantities.
	 */
	public PizzaTypeSummary(String typeName, int numberOfOrders, int numberOfPizzas, int summaryPrice) throws IllegalArgumentException{
		if(typeName.isEmpty()) {
			String msg = "Empty type name " + numberOfOrders + " " + numberOfPizzas + " " + summaryPrice;
			throw new IllegalArgumentException(msg);
		}
		if(numberOfOrders < 0) {
			String msg = "Negative orders " + typeName + " " + numberOfOrders + " " + numberOfPizzas + " " + summaryPrice;
			throw new IllegalArgumentException(msg);			
		}
		if(numberOfPizzas < 0) {
			String msg = "Negative pizzas " + typeName + " " + numberOfOrders + " " + numberOfPizzas + " " + summaryPrice;
			throw new IllegalArgumentException(msg);			
		}
		if(summaryPrice < 0) {
			String msg = "Negative price " + typeName + " " + numberOfOrders + " " + numberOfPizzas + " " + summaryPrice;
			throw new IllegalArgumentException(msg);			
		}
		this.typeName = typeName;
		this.numberOfOrders = numberOfOrders;
		this.numberOfPizzas = numberOfPizzas;
		this.totalRevenue = summaryPrice;
	}

	@Override
	public String getTypeName() {
		return typeName;
	}
	public void setTypeName(String typeName) {
		this.typeName = typeName;
	}
	@Override
	public int getNumberOfOrders() {
		return this.numberOfOrders;
	}
	public void setNumberOfOrders(int numberOfOrders) {
		this.numberOfOrders = numberOfOrders;
	}
	@Override
	public int getNumberOfPizzas() {
		return this.numberOfPizzas;
	}
	public void setNumberOfPizzas(int numberOfPizzas) {
		this.numberOfPizzas = numberOfPizzas;
	}
	@Override
	public int getTotalRevenue() {
		return totalRevenue;
	}
	public void setTotalRevenue(int summaryPrice) {
		this.totalRevenue = summaryPrice;
	}


	@Override
	public String toString() {
		return "PizzaTypeSummary [getTypeName()=" + getTypeName() + ", getNumberOfOrders()=" + getNumberOfOrders()
				+ ", getNumberOfPizzas()=" + getNumberOfPizzas() + ", getTotalRevenue()=" + getTotalRevenue() + "]";
	}
	
}
