package engine;

import static org.junit.Assert.*;

import java.util.List;

import org.junit.Test;

import dom.Order;

public class PizzariaEngineTest {

	@Test
	public final void testAddOrderHappy() {
		PizzariaEngine engine = new PizzariaEngine();
		String type =""; int qty = 0;
		
		type = "super"; qty = 12;
		engine.addOrder(type, qty);
		type = "duper"; qty = 1;
		engine.addOrder(type, qty);
		type = "super"; qty = 1;
		engine.addOrder(type, qty);
		type = "super"; qty = 2;
		engine.addOrder(type, qty);
		type = "duper"; qty = 2;
		engine.addOrder(type, qty);

		List<Order> currentOrders = engine.getAllOrders();
		int expectedSize = 5;
		int actualSize = currentOrders.size();
		assertEquals(expectedSize, actualSize);
		
		Order randomOrder = currentOrders.get(3);
		assertEquals(2, randomOrder.getQuantity());
		assertEquals("super", randomOrder.getType());
	}

	@Test
	public final void testAddOrderRainy() {
		PizzariaEngine engine = new PizzariaEngine();
		String type =""; int qty = 0;
		
		type = "super"; qty = 12;
		engine.addOrder(type, qty);
		type = "duper"; qty = 1;
		engine.addOrder(type, qty);
		type = "super"; qty = 1;
		engine.addOrder(type, qty);
		type = "super"; qty = 2;
		engine.addOrder(type, qty);
		type = "duper"; qty = 2;
		engine.addOrder(type, qty);
		type = "duper"; qty = -2;
		engine.addOrder(type, qty);
		type = ""; qty = 2;
		engine.addOrder(type, qty);
		
		List<Order> currentOrders = engine.getAllOrders();
		//TODO FIX? Only 5 should pass in the list
		//The engine does not prevent the empty type order yet
		//Luckily, the reporter ignores problematic records
		int expectedSize = 5;		
		int actualSize = currentOrders.size();
		assertEquals(expectedSize, actualSize);
		
		Order randomOrder = currentOrders.get(4);
		assertEquals(2, randomOrder.getQuantity());
		assertEquals("duper", randomOrder.getType());
	}
	
	
	@Test
	public final void testProduceReport() {
		PizzariaEngine engine = new PizzariaEngine();
		String type =""; int qty = 0;
		
		type = "super"; qty = 12;
		engine.addOrder(type, qty);
		type = "duper"; qty = 1;
		engine.addOrder(type, qty);
		type = "super"; qty = 1;
		engine.addOrder(type, qty);
		type = "super"; qty = 2;
		engine.addOrder(type, qty);
		type = "duper"; qty = 2;
		engine.addOrder(type, qty);
		
		List<String> results = engine.produceReport();
		assertEquals("PizzaTypeSummary [getTypeName()=super, getNumberOfOrders()=3, getNumberOfPizzas()=15, getTotalRevenue()=150]", results.get(0).trim());
		assertEquals("PizzaTypeSummary [getTypeName()=duper, getNumberOfOrders()=2, getNumberOfPizzas()=3, getTotalRevenue()=30]", results.get(1).trim());
	}

}
